==> haskell-hasql-transaction-1.0.1.1-271-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-ZE6y0VbRKy6InDxQTqWfR
key:                  hasql-transaction-1.0.1.1-ZE6y0VbRKy6InDxQTqWfR
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  d894d4d05c9e278b30e2f9f317c1c4cf
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-ZE6y0VbRKy6InDxQTqWfR
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    bytestring-tree-builder-0.2.7.10-FvAU540AT38FGeuCjrcjF3
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    contravariant-extras-0.3.5.4-KQODmY3btn6QQJWMypRoY
    hasql-1.5.0.4-4Vii0IJVUqh8L4c7BRjtf9 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-272-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-Klg7CKug5d8K70LFq2haCw
key:                  hasql-transaction-1.0.1.1-Klg7CKug5d8K70LFq2haCw
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  6cee059f034cec288b0582fe1957b838
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-Klg7CKug5d8K70LFq2haCw
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    bytestring-tree-builder-0.2.7.10-6pJ8k1HbdPRIrS0HWs3WT5
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    contravariant-extras-0.3.5.4-KQODmY3btn6QQJWMypRoY
    hasql-1.5.0.4-6NVskNrbFAOJPVX8CExyyl mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
